containertools.eject_contents_of_container
==========================================

.. autofunction:: abjad.tools.containertools.eject_contents_of_container.eject_contents_of_container
   :noindex:
